# Easy PIL
A python library built on top of PIL to easily edit images. 

# Usage
[Documentaion](https://easy-pil.readthedocs.io/en/latest/)

[Examples](https://github.com/shahriyardx/easy-pil/tree/master/examples)

[Tutorials](https://youtube.com/playlist?list=PLb_oBhGqAlbT4yVqV0TSXggA8b0lZhGhn)